@@ -1,6 +1,10 @@
 class FailedToFindASolutionError(Exception):
-    pass
+    ...
 
 
 class SolverNotSupportedError(Exception):
-    pass
+    ...
+
+
+class InvalidWordleBotFileError(Exception):
+    ...
