@@ -2,12 +2,11 @@ from __future__ import annotations
 
 from typing import Sequence
 
-from doddle.guess import Guess
-
 from .benchmarking import Benchmarker, BenchmarkReporter, SimulBenchmarker
 from .engine import Engine, SimulEngine
 from .enums import SolverType
 from .exceptions import SolverNotSupportedError
+from .guess import Guess
 from .histogram import HistogramBuilder
 from .scoring import Scorer
 from .simul_solver import EntropySimulSolver, MinimaxSimulSolver, SimulSolver
